unit PRP18_h;

interface
////////////////////////////////////////////////////////////////////////////////

uses
  SysUtils,
  Classes,
  Windows;

const
  DLL_NAME = 'PRP18.dll';

const
  DEFAULT_READER_ADDR = 1;
  MAX_UID_TYPEA_LEN   = 7;
  UID_AUT_LENGTH      = 4;
  MIF_BLOCK_SIZE      = 16;
  MIFC_KEY_LENGTH     = 6;
  AES_KEY_SIZE        = 16;
  MAX_BLOCKS_RW       = 3;
  MAX_MIF_SECTORS     = 40;
  //
  PHHAL_HW_MFC_KEYA   = $0A;   // MIFARE Classic Key Type A
  PHHAL_HW_MFC_KEYB   = $0B;   // MIFARE Classic Key Type B

function Enumerate(): uint16; cdecl; external DLL_NAME;
function GetFirstReader(desc: pbytearray; maxlen: short): uint16; cdecl; external DLL_NAME;
function GetNextReader(desc: pbytearray; maxlen: short): uint16; cdecl; external DLL_NAME;
function ReaderOpened(num: short): uint16; cdecl; external DLL_NAME;
function GetReaderSerial(num: short; var ser: dword): uint16; cdecl; external DLL_NAME;
function GetReaderSerialStr(num: short; serstr: pbytearray): uint16; cdecl; external DLL_NAME;
function OpenByNum(num: short): uint16; cdecl; external DLL_NAME;
function CloseByNum(num: short): uint16; cdecl; external DLL_NAME;

// Utilites
function BlockToSector4k(block: uint16): uint16; cdecl; external DLL_NAME;
function SectorToBlock4k(sect: uint16): uint16; cdecl; external DLL_NAME;
//
//    
function ReaderSoftReset(): uint16; cdecl; external DLL_NAME;
function TestTranceive(var len: uint16; data: PByteArray): uint16; cdecl; external DLL_NAME;
function BeepBlink(led: uint8; beep: uint8; time: uint8): uint16; cdecl;  external DLL_NAME;
function ReadRegister(addr: uint16; var data: uint16): uint16; cdecl;  external DLL_NAME;
function WriteRegister(addr, data: uint16): uint16; cdecl;  external DLL_NAME;
function RfFieldControl(control: uint8): uint16; cdecl;  external DLL_NAME;
function GetReaderId(data: pbytearray): uint16; cdecl; external DLL_NAME;
//
function InitReaderSeproData(sign: uint8; sector: uint8; profile: uint8; dummy: uint8): uint16; cdecl; external DLL_NAME;
function GetReaderSeproData(var sign: uint8; var sector: uint8; var profile: uint8; var dummy: uint8): uint16; cdecl; external DLL_NAME;


// FUNCTIONS LEVEL 3 and 4
function ActivateCardA3(var uidlen: uint8; uid: pbytearray;
                        var sak: uint8; var mca: uint8): uint16; cdecl;  external DLL_NAME;
function ActivateCardA4(usepps: uint8; var uidlen: uint8; uid: pbytearray;
                        var sak: uint8; var mca: uint8;
                        // Level 4 ISO params
                        var ats: uint8; var ciden: uint8; var cid: uint8;
                        var fsdi: uint8; var fsci: uint8): uint16; cdecl; external DLL_NAME;
// Exetended version with ATQA in responce
function ActivateCardA3Ex(var uidlen: uint8; uid: pbytearray;
                        var atqa: uint16; var sak: uint8; var mca: uint8): uint16; cdecl;  external DLL_NAME;
function ActivateCardA4Ex(usepps: uint8; var uidlen: uint8; uid: pbytearray;
                        var atqa: uint16; var sak: uint8; var mca: uint8;
                        // Level 4 ISO params
                        var ats: uint8; var ciden: uint8; var cid: uint8;
                        var fsdi: uint8; var fsci: uint8): uint16; cdecl; external DLL_NAME;
function HaltA(): uint16; cdecl; external DLL_NAME;
function Exchange3A(InData: pbytearray; inlen: uint16; OutData: pbytearray; var outlen: uint16): uint16; cdecl; external DLL_NAME;
function ExchangeApdu(InData: pbytearray; inlen: uint16; OutData: pbytearray; var outlen: uint16): uint16; cdecl; external DLL_NAME;

// FUNCTIONS MIFARE CLASSIC
function MfcAuthenticateKey(block: uint16; key_type: uint8; pUid: pbytearray;
                                   pKey: pbytearray): uint16; cdecl; external DLL_NAME;
function MfcAuthentKeyNo(block: uint16; key_type: uint8; pUid: pbytearray;
                                key_no: uint16; key_version: uint16): uint16; cdecl; external DLL_NAME;
function MfcReadBlock(block: uint16; pBlockData: pbytearray): uint16; cdecl; external DLL_NAME;
function MfcWriteBlock(block: uint16; pBlockData: pbytearray): uint16; cdecl; external DLL_NAME;
function MfcStoreKeyE2(key_no: uint8; num_keys: uint8; keys: pbytearray): uint16; cdecl; external DLL_NAME;
function MfcReadSector(sector: uint16; var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function MfcWriteSector(sector: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;

// FUNCTIONS MIFARE PLUS
function WritePerso(block: uint16; key: pbytearray): uint16; cdecl; external DLL_NAME;
function CommitPerso(): uint16; cdecl; external DLL_NAME;
function MifPlusAuthSl3(first: uint8; keyblock: uint16; keyind: uint16): uint16; cdecl; external DLL_NAME;
function MifPlusAuthSl3Key(first: uint8; keyblock: uint16; key: pbytearray): uint16; cdecl; external DLL_NAME;
function MifPlusReadBlocks(encripted: uint8; readmaced: uint8; maconcmd: uint8;
                           block: uint16; blockcount: uint8; data: pbytearray): uint16; cdecl; external DLL_NAME;
function MifPlusWriteBlocks(encripted: uint8; maconresp: uint8; block: uint16;
                            blockcount: uint8; data: pbytearray): uint16; cdecl; external DLL_NAME;
function MifPlusReadSector(encripted: uint8; readmaced: uint8; maconcmd: uint8;
                           sector: uint16; var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function MifPlusWriteSector(encripted: uint8; maconresp: uint8; sector: uint16;
                            data: pbytearray): uint16; cdecl; external DLL_NAME;
function MifPlusChangeAesKey(maced: uint8; block: uint16; key: pbytearray): uint16; cdecl; external DLL_NAME;


// COMPLEX COMMANDS AND I-CODE
function ReadBankAsn(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function ReadBankAsnCoded(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function ReadParsecSmart(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function ReadCardB(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function ReadCardBCoded(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function ReadCardICode(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
// Version 2.5 september 2020
function ReadBankCardPan(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
// Added 2021, April, PR-P18 version 3.2, DLL version 2.4.6.6
function ReadCardPanHash(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
// Added 2022-06 for read full PAN in text format
function ReadCardPanFull(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;

// Utility functions
function WriteAesKeyToEe(sector: uint8; keytype: uint8; key: pbytearray): uint16; cdecl; external DLL_NAME;

//  Added for PR-X18
function ReadCardEM(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function ReadCardHid(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
function ReadCardCP(var size: uint16; data: pbytearray): uint16; cdecl; external DLL_NAME;
//
function HostGetExecutionTime(var ms: uint32): uint16; cdecl; external DLL_NAME;
function HostTransTmrStart(): uint16; cdecl; external DLL_NAME;
function HostTransTmrStop(var ms: uint32): uint16; cdecl; external DLL_NAME;



////////////////////////////////////////////////////////////////////////////////
implementation

end.
